``zope.browsermenu``
====================

.. image:: https://travis-ci.org/zopefoundation/zope.browsermenu.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.browsermenu

.. note:: 
   This package is at present not reusable without depending on a large
   chunk of the Zope Toolkit and its assumptions. It is maintained by the
   `Zope Toolkit project <http://docs.zope.org/zopetoolkit/>`_.

This package provides an implementation of browser menus and ZCML directives
for configuring them.
